import argparse
import jsondiff
import json
import warnings
import sys

def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("first")
    parser.add_argument("second")
    parser.add_argument("-p", "--patch", action="store_true", default=False)
    parser.add_argument("-s", "--syntax", action="store", type=str, default="compact")
    parser.add_argument("-i", "--indent", action="store", type=int, default=None)

    args = parser.parse_args()

    with open(args.first, "r") as f:
        with open(args.second, "r") as g:
            jf = json.load(f)
            jg = json.load(g)
            if args.patch:
                x = jsondiff.patch(
                    jf,
                    jg,
                    marshal=True,
                    syntax=args.syntax
                )
            else:
                x = jsondiff.diff(
                    jf,
                    jg,
                    marshal=True,
                    syntax=args.syntax
                )

            json.dump(x, sys.stdout, indent=args.indent)

def main_deprecated():
    warnings.warn("jsondiff is deprecated. Use jdiff instead.", DeprecationWarning)
    main()

if __name__ == '__main__':
    main()



import os
import re
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), 'jsondiff', '__init__.py')) as f:
    version = re.compile(r".*__version__ = '(.*?)'", re.S).match(f.read()).group(1)

setup(
    name='jsondiff',
    packages=find_packages(exclude=['tests']),
    version=version,
    description='Diff JSON and JSON-like structures in Python',
    author='Zoomer Analytics LLC',
    author_email='eric.reynolds@zoomeranalytics.com',
    url='https://github.com/ZoomerAnalytics/jsondiff',
    keywords=['json', 'diff', 'diffing', 'difference', 'patch', 'delta', 'dict', 'LCS'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
    ],
    entry_points={
        'console_scripts': [
            'jsondiff=jsondiff.cli:main_deprecated',
            'jdiff=jsondiff.cli:main'
        ]
    }
)
